==> jc-1.4.0.tar.gz: javax/print/attribute/standard/JobStateReason.h <==
// public class javax.print.attribute.standard.JobStateReason

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 96da48e7223778b9 javax_print_attribute_EnumSyntax
// @dep_class f55b81ef0d394d90 javax_print_attribute_standard_JobStateReason

// header file dependencies
// @dep_header javax_print_attribute_EnumSyntax

#include "javax/print/attribute/EnumSyntax.h"

#ifndef _JC_javax_print_attribute_standard_JobStateReason_H_
#define _JC_javax_print_attribute_standard_JobStateReason_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_print_attribute_standard_JobStateReason$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_JobStateReason$sub_refs	_jc_javax_print_attribute_standard_JobStateReason$sub_refs;
typedef struct _jc_javax_print_attribute_standard_JobStateReason$sub_nonrefs	_jc_javax_print_attribute_standard_JobStateReason$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_JobStateReason$refs	_jc_javax_print_attribute_standard_JobStateReason$refs;
typedef struct _jc_javax_print_attribute_standard_JobStateReason$nonrefs	_jc_javax_print_attribute_standard_JobStateReason$nonrefs;
typedef struct _jc_javax_print_attribute_standard_JobStateReason$object	_jc_javax_print_attribute_standard_JobStateReason$object;

typedef struct _jc_javax_print_attribute_standard_JobStateReason$fields_struct	_jc_javax_print_attribute_standard_JobStateReason$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_JobStateReason$vmethods	_jc_javax_print_attribute_standard_JobStateReason$vmethods;
typedef const struct _jc_javax_print_attribute_standard_JobStateReason$vtable	_jc_javax_print_attribute_standard_JobStateReason$vtable;
typedef const struct _jc_javax_print_attribute_standard_JobStateReason$vtype	_jc_javax_print_attribute_standard_JobStateReason$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_JobStateReason$fields_struct {
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*ABORTED__5fBY__5fSYSTEM;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*COMPRESSION__5fERROR;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*DOCUMENT__5fACCESS__5fERROR;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*DOCUMENT__5fFORMAT__5fERROR;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fCANCELED__5fAT__5fDEVICE;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fCANCELED__5fBY__5fOPERATOR;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fCANCELED__5fBY__5fUSER;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fCOMPLETED__5fSUCCESSFULLY;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fCOMPLETED__5fWITH__5fERRORS;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fCOMPLETED__5fWITH__5fWARNINGS;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fDATA__5fINSUFFICIENT;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fHOLD__5fUNTIL__5fSPECIFIED;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fINCOMING;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fINTERPRETING;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fOUTGOING;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fPRINTING;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fQUEUED;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fQUEUED__5fFOR__5fMARKER;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fRESTARTABLE;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fTRANSFORMING;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*PRINTER__5fSTOPPED;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*PRINTER__5fSTOPPED__5fPARTLY;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*PROCESSING__5fTO__5fSTOP__5fPOINT;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*QUEUED__5fIN__5fDEVICE;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*RESOURCES__5fARE__5fNOT__5fREADY;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*SERVICE__5fOFF__5fLINE;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*SUBMISSION__5fINTERRUPTED;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*UNSUPPORTED__5fCOMPRESSION;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*UNSUPPORTED__5fDOCUMENT__5fFORMAT;
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24JobStateReason;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_JobStateReason$fields_struct _jc_javax_print_attribute_standard_JobStateReason$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_JobStateReason$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_print_attribute_standard_JobStateReason$object *, jint);

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_JobStateReason$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_JobStateReason$object *);
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_JobStateReason$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_JobStateReason$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_JobStateReason$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_JobStateReason$method_info$getName$bec186f2ce7e1882;

// Static methods
extern void _jc_javax_print_attribute_standard_JobStateReason$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_JobStateReason$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_print_attribute_standard_JobStateReason$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_JobStateReason$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_JobStateReason$object *);
};

// Vtable
struct _jc_javax_print_attribute_standard_JobStateReason$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_EnumSyntax$vmethods	javax_print_attribute_EnumSyntax;
	_jc_javax_print_attribute_standard_JobStateReason$vmethods	javax_print_attribute_standard_JobStateReason;
};

// Vtype
struct _jc_javax_print_attribute_standard_JobStateReason$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_JobStateReason$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_JobStateReason$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_JobStateReason$refs {
    _jc_javax_print_attribute_standard_JobStateReason$sub_refs	javax_print_attribute_standard_JobStateReason;
    _jc_javax_print_attribute_EnumSyntax$sub_refs	javax_print_attribute_EnumSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_JobStateReason$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_JobStateReason$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_EnumSyntax$sub_nonrefs	javax_print_attribute_EnumSyntax;
    _jc_javax_print_attribute_standard_JobStateReason$sub_nonrefs	javax_print_attribute_standard_JobStateReason;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_JobStateReason$object {
	_jc_javax_print_attribute_standard_JobStateReason$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_JobStateReason$vtype	*vtype;
	_jc_javax_print_attribute_standard_JobStateReason$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_JobStateReason$vtype _jc_javax_print_attribute_standard_JobStateReason$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_JobStateReason, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_JobStateReason$class_object;

#endif	/* _JC_javax_print_attribute_standard_JobStateReason_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/standard/JobStateReason.h <==
// public class javax.print.attribute.standard.JobStateReason

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 96da48e7223778b9 javax_print_attribute_EnumSyntax
// @dep_class f55b81ef0d394d90 javax_print_attribute_standard_JobStateReason

// header file dependencies
// @dep_header javax_print_attribute_EnumSyntax

#include "javax/print/attribute/EnumSyntax.h"

#ifndef _JC_javax_print_attribute_standard_JobStateReason_H_
#define _JC_javax_print_attribute_standard_JobStateReason_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_print_attribute_standard_JobStateReason$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_JobStateReason$sub_refs	_jc_javax_print_attribute_standard_JobStateReason$sub_refs;
typedef struct _jc_javax_print_attribute_standard_JobStateReason$sub_nonrefs	_jc_javax_print_attribute_standard_JobStateReason$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_JobStateReason$refs	_jc_javax_print_attribute_standard_JobStateReason$refs;
typedef struct _jc_javax_print_attribute_standard_JobStateReason$nonrefs	_jc_javax_print_attribute_standard_JobStateReason$nonrefs;
typedef struct _jc_javax_print_attribute_standard_JobStateReason$object	_jc_javax_print_attribute_standard_JobStateReason$object;

typedef struct _jc_javax_print_attribute_standard_JobStateReason$fields_struct	_jc_javax_print_attribute_standard_JobStateReason$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_JobStateReason$vmethods	_jc_javax_print_attribute_standard_JobStateReason$vmethods;
typedef const struct _jc_javax_print_attribute_standard_JobStateReason$vtable	_jc_javax_print_attribute_standard_JobStateReason$vtable;
typedef const struct _jc_javax_print_attribute_standard_JobStateReason$vtype	_jc_javax_print_attribute_standard_JobStateReason$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_JobStateReason$fields_struct {
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*ABORTED__5fBY__5fSYSTEM;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*COMPRESSION__5fERROR;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*DOCUMENT__5fACCESS__5fERROR;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*DOCUMENT__5fFORMAT__5fERROR;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fCANCELED__5fAT__5fDEVICE;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fCANCELED__5fBY__5fOPERATOR;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fCANCELED__5fBY__5fUSER;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fCOMPLETED__5fSUCCESSFULLY;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fCOMPLETED__5fWITH__5fERRORS;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fCOMPLETED__5fWITH__5fWARNINGS;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fDATA__5fINSUFFICIENT;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fHOLD__5fUNTIL__5fSPECIFIED;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fINCOMING;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fINTERPRETING;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fOUTGOING;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fPRINTING;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fQUEUED;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fQUEUED__5fFOR__5fMARKER;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fRESTARTABLE;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*JOB__5fTRANSFORMING;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*PRINTER__5fSTOPPED;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*PRINTER__5fSTOPPED__5fPARTLY;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*PROCESSING__5fTO__5fSTOP__5fPOINT;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*QUEUED__5fIN__5fDEVICE;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*RESOURCES__5fARE__5fNOT__5fREADY;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*SERVICE__5fOFF__5fLINE;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*SUBMISSION__5fINTERRUPTED;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*UNSUPPORTED__5fCOMPRESSION;
	struct _jc_javax_print_attribute_standard_JobStateReason$object	*UNSUPPORTED__5fDOCUMENT__5fFORMAT;
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24JobStateReason;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_JobStateReason$fields_struct _jc_javax_print_attribute_standard_JobStateReason$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_JobStateReason$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_print_attribute_standard_JobStateReason$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_JobStateReason$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_JobStateReason$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_JobStateReason$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_JobStateReason$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_JobStateReason$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_JobStateReason$method_info$getName$bec186f2ce7e1882;

// Static methods
extern void _jc_javax_print_attribute_standard_JobStateReason$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_JobStateReason$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_standard_JobStateReason$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_JobStateReason$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_JobStateReason$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_attribute_standard_JobStateReason$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_EnumSyntax$vmethods	javax_print_attribute_EnumSyntax;
	_jc_javax_print_attribute_standard_JobStateReason$vmethods	javax_print_attribute_standard_JobStateReason;
};

// Vtype
struct _jc_javax_print_attribute_standard_JobStateReason$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_JobStateReason$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_JobStateReason$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_JobStateReason$refs {
    _jc_javax_print_attribute_standard_JobStateReason$sub_refs	javax_print_attribute_standard_JobStateReason;
    _jc_javax_print_attribute_EnumSyntax$sub_refs	javax_print_attribute_EnumSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_JobStateReason$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_JobStateReason$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_EnumSyntax$sub_nonrefs	javax_print_attribute_EnumSyntax;
    _jc_javax_print_attribute_standard_JobStateReason$sub_nonrefs	javax_print_attribute_standard_JobStateReason;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_JobStateReason$object {
	_jc_javax_print_attribute_standard_JobStateReason$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_JobStateReason$vtype	*vtype;
	_jc_javax_print_attribute_standard_JobStateReason$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_JobStateReason$vtype _jc_javax_print_attribute_standard_JobStateReason$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_JobStateReason, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_JobStateReason$class_object;

#endif	/* _JC_javax_print_attribute_standard_JobStateReason_H_ */
